@@ -8,9 +8,8 @@ use crate::header;
 #[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
 #[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
 pub struct Deanery {
-    #[serde(rename = "Diocese")]
-    #[serde(skip_serializing_if="Option::is_none")]
-    pub diocese: Option<models::Diocese>,
+    #[serde(rename = "diocese")]
+    pub diocese: models::Diocese,
 
     #[serde(rename = "id")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -19,18 +18,18 @@ pub struct Deanery {
     #[serde(rename = "name")]
     pub name: String,
 
-    #[serde(rename = "inCharge")]
-    pub in_charge: String,
+    #[serde(rename = "personInCharge")]
+    pub person_in_charge: String,
 
 }
 
 impl Deanery {
-    pub fn new(name: String, in_charge: String, ) -> Deanery {
+    pub fn new(diocese: models::Diocese, name: String, person_in_charge: String, ) -> Deanery {
         Deanery {
-            diocese: None,
+            diocese: diocese,
             id: None,
             name: name,
-            in_charge: in_charge,
+            person_in_charge: person_in_charge,
         }
     }
 }
@@ -41,7 +40,7 @@ impl Deanery {
 impl std::string::ToString for Deanery {
     fn to_string(&self) -> String {
         let mut params: Vec<String> = vec![];
-        // Skipping Diocese in query parameter serialization
+        // Skipping diocese in query parameter serialization
 
         // Skipping id in query parameter serialization
 
@@ -50,8 +49,8 @@ impl std::string::ToString for Deanery {
         params.push(self.name.to_string());
 
 
-        params.push("inCharge".to_string());
-        params.push(self.in_charge.to_string());
+        params.push("personInCharge".to_string());
+        params.push(self.person_in_charge.to_string());
 
         params.join(",").to_string()
     }
@@ -70,7 +69,7 @@ impl std::str::FromStr for Deanery {
             pub diocese: Vec<models::Diocese>,
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
-            pub in_charge: Vec<String>,
+            pub person_in_charge: Vec<String>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -87,10 +86,10 @@ impl std::str::FromStr for Deanery {
 
             if let Some(key) = key_result {
                 match key {
-                    "Diocese" => intermediate_rep.diocese.push(<models::Diocese as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "diocese" => intermediate_rep.diocese.push(<models::Diocese as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "inCharge" => intermediate_rep.in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing Deanery".to_string())
                 }
             }
@@ -101,10 +100,10 @@ impl std::str::FromStr for Deanery {
 
         // Use the intermediate representation to return the struct
         std::result::Result::Ok(Deanery {
-            diocese: intermediate_rep.diocese.into_iter().next(),
+            diocese: intermediate_rep.diocese.into_iter().next().ok_or("diocese missing in Deanery".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Deanery".to_string())?,
-            in_charge: intermediate_rep.in_charge.into_iter().next().ok_or("inCharge missing in Deanery".to_string())?,
+            person_in_charge: intermediate_rep.person_in_charge.into_iter().next().ok_or("personInCharge missing in Deanery".to_string())?,
         })
     }
 }
@@ -162,18 +161,18 @@ pub struct Diocese {
     #[serde(rename = "name")]
     pub name: String,
 
-    #[serde(rename = "inCharge")]
-    pub in_charge: String,
+    #[serde(rename = "personInCharge")]
+    pub person_in_charge: String,
 
 }
 
 impl Diocese {
-    pub fn new(ecclesiastical_province: models::EcclesiasticalProvince, name: String, in_charge: String, ) -> Diocese {
+    pub fn new(ecclesiastical_province: models::EcclesiasticalProvince, name: String, person_in_charge: String, ) -> Diocese {
         Diocese {
             ecclesiastical_province: ecclesiastical_province,
             id: None,
             name: name,
-            in_charge: in_charge,
+            person_in_charge: person_in_charge,
         }
     }
 }
@@ -193,8 +192,8 @@ impl std::string::ToString for Diocese {
         params.push(self.name.to_string());
 
 
-        params.push("inCharge".to_string());
-        params.push(self.in_charge.to_string());
+        params.push("personInCharge".to_string());
+        params.push(self.person_in_charge.to_string());
 
         params.join(",").to_string()
     }
@@ -213,7 +212,7 @@ impl std::str::FromStr for Diocese {
             pub ecclesiastical_province: Vec<models::EcclesiasticalProvince>,
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
-            pub in_charge: Vec<String>,
+            pub person_in_charge: Vec<String>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -233,7 +232,7 @@ impl std::str::FromStr for Diocese {
                     "ecclesiasticalProvince" => intermediate_rep.ecclesiastical_province.push(<models::EcclesiasticalProvince as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "inCharge" => intermediate_rep.in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing Diocese".to_string())
                 }
             }
@@ -247,7 +246,7 @@ impl std::str::FromStr for Diocese {
             ecclesiastical_province: intermediate_rep.ecclesiastical_province.into_iter().next().ok_or("ecclesiasticalProvince missing in Diocese".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Diocese".to_string())?,
-            in_charge: intermediate_rep.in_charge.into_iter().next().ok_or("inCharge missing in Diocese".to_string())?,
+            person_in_charge: intermediate_rep.person_in_charge.into_iter().next().ok_or("personInCharge missing in Diocese".to_string())?,
         })
     }
 }
@@ -346,19 +345,19 @@ pub struct Parish {
     #[serde(rename = "name")]
     pub name: String,
 
-    #[serde(rename = "inCharge")]
-    pub in_charge: String,
+    #[serde(rename = "personInCharge")]
+    pub person_in_charge: String,
 
 }
 
 impl Parish {
-    pub fn new(diocese: models::Diocese, deanery: models::Deanery, name: String, in_charge: String, ) -> Parish {
+    pub fn new(diocese: models::Diocese, deanery: models::Deanery, name: String, person_in_charge: String, ) -> Parish {
         Parish {
             diocese: diocese,
             deanery: deanery,
             id: None,
             name: name,
-            in_charge: in_charge,
+            person_in_charge: person_in_charge,
         }
     }
 }
@@ -380,8 +379,8 @@ impl std::string::ToString for Parish {
         params.push(self.name.to_string());
 
 
-        params.push("inCharge".to_string());
-        params.push(self.in_charge.to_string());
+        params.push("personInCharge".to_string());
+        params.push(self.person_in_charge.to_string());
 
         params.join(",").to_string()
     }
@@ -401,7 +400,7 @@ impl std::str::FromStr for Parish {
             pub deanery: Vec<models::Deanery>,
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
-            pub in_charge: Vec<String>,
+            pub person_in_charge: Vec<String>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -422,7 +421,7 @@ impl std::str::FromStr for Parish {
                     "deanery" => intermediate_rep.deanery.push(<models::Deanery as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "inCharge" => intermediate_rep.in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing Parish".to_string())
                 }
             }
@@ -437,7 +436,7 @@ impl std::str::FromStr for Parish {
             deanery: intermediate_rep.deanery.into_iter().next().ok_or("deanery missing in Parish".to_string())?,
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Parish".to_string())?,
-            in_charge: intermediate_rep.in_charge.into_iter().next().ok_or("inCharge missing in Parish".to_string())?,
+            person_in_charge: intermediate_rep.person_in_charge.into_iter().next().ok_or("personInCharge missing in Parish".to_string())?,
         })
     }
 }
@@ -491,17 +490,17 @@ pub struct Polity {
     #[serde(rename = "name")]
     pub name: String,
 
-    #[serde(rename = "inCharge")]
-    pub in_charge: String,
+    #[serde(rename = "personInCharge")]
+    pub person_in_charge: String,
 
 }
 
 impl Polity {
-    pub fn new(name: String, in_charge: String, ) -> Polity {
+    pub fn new(name: String, person_in_charge: String, ) -> Polity {
         Polity {
             id: None,
             name: name,
-            in_charge: in_charge,
+            person_in_charge: person_in_charge,
         }
     }
 }
@@ -519,8 +518,8 @@ impl std::string::ToString for Polity {
         params.push(self.name.to_string());
 
 
-        params.push("inCharge".to_string());
-        params.push(self.in_charge.to_string());
+        params.push("personInCharge".to_string());
+        params.push(self.person_in_charge.to_string());
 
         params.join(",").to_string()
     }
@@ -538,7 +537,7 @@ impl std::str::FromStr for Polity {
         struct IntermediateRep {
             pub id: Vec<uuid::Uuid>,
             pub name: Vec<String>,
-            pub in_charge: Vec<String>,
+            pub person_in_charge: Vec<String>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -557,7 +556,7 @@ impl std::str::FromStr for Polity {
                 match key {
                     "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "inCharge" => intermediate_rep.in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "personInCharge" => intermediate_rep.person_in_charge.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing Polity".to_string())
                 }
             }
@@ -570,7 +569,7 @@ impl std::str::FromStr for Polity {
         std::result::Result::Ok(Polity {
             id: intermediate_rep.id.into_iter().next(),
             name: intermediate_rep.name.into_iter().next().ok_or("name missing in Polity".to_string())?,
-            in_charge: intermediate_rep.in_charge.into_iter().next().ok_or("inCharge missing in Polity".to_string())?,
+            person_in_charge: intermediate_rep.person_in_charge.into_iter().next().ok_or("personInCharge missing in Polity".to_string())?,
         })
     }
 }
